aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/pdf/SkPDFPage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pdf/SkPDFPage.h')
-rw-r--r--src/pdf/SkPDFPage.h6
1 files changed, 2 insertions, 4 deletions
diff --git a/src/pdf/SkPDFPage.h b/src/pdf/SkPDFPage.h
index 2ce773c017..285a2f565e 100644
--- a/src/pdf/SkPDFPage.h
+++ b/src/pdf/SkPDFPage.h
@@ -40,15 +40,13 @@ public:
* that the page is part of.
* @param catalog The catalog to add page content objects to.
* @param firstPage Indicate if this is the first page of a document.
* @param newResourceObjects All the resource objects (recursively) used on
* the page are added to this array. This gives
* the caller a chance to deduplicate resources
* across pages.
- * @param knownResourceObjects The set of resources to be ignored.
*/
void finalizePage(SkPDFCatalog* catalog, bool firstPage,
- const SkTSet<SkPDFObject*>& knownResourceObjects,
- SkTSet<SkPDFObject*>* newResourceObjects);
+ SkTDArray<SkPDFObject*>* resourceObjects);
/** Add destinations for this page to the supplied dictionary.
* @param dict Dictionary to add destinations to.
@@ -40,15 +40,13 @@ public:
* @param catalog The catalog to add page content objects to.
* @param firstPage Indicate if this is the first page of a document.
- * @param newResourceObjects All the resource objects (recursively) used on
+ * @param resourceObjects All the resource objects (recursively) used on
* the page are added to this array. This gives
* the caller a chance to deduplicate resources